CalendarListViewerMonthHeader class final

Constructors

CalendarListViewerMonthHeader({double spacing = 8, CrossAxisAlignment crossAlignment = CrossAxisAlignment.start, IndexedWidgetBuilder? builder})
const

Properties

builder IndexedWidgetBuilder?
final
crossAlignment CrossAxisAlignment
final
hasBuilder bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited