CalendarReservationData class final

Constructors

CalendarReservationData({required int weekDays, required bool hasPrevious, required bool hasNext, required CalendarReservationUser user})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNext bool
final
hasPrevious bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user CalendarReservationUser
final
weekDays int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited