CalendarReservationUser class final

Constructors

CalendarReservationUser({String? id, required String name, String? netImage, String? assetImage, Object? data})
const

Properties

assetImage String?
final
data Object?
final
hasAssetImage bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasNetImage bool
no setter
id String?
final
name String
final
netImage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited