CalendarViewerReservation class final

Constructors

CalendarViewerReservation({required DateTime from, required DateTime to, required CalendarReservationUser user})
const

Properties

from DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to DateTime
final
user CalendarReservationUser
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited